Edition control — CubicWeb 3.13.2

### Navigation

- index
- modules |
- next |
- previous |
- CubicWeb 3.13.2 »
- Web side development »

# Edition control

This chapter covers the editing capabilities of CubicWeb. It explains html Form construction, the Edit Controller and their interactions.

- HTML form construction
  - Exploring the available forms
  - The Automatic Entity Form
  - Anatomy of a choices function
  - Building self-posted form with custom fields/widgets
  - APIs
- Dissection of an entity form
  - Populating the database
  - Looking at the html output
- The form validation process
  - Preparation
  - Validation loop
  - Explanation
- The edit controller
  - Edition handling
  - Redirection control
- Examples
  - (Automatic) Entity form
  - Ad-hoc fields form

### Navigation

- index
- modules |
- next |
- previous |
- CubicWeb 3.13.2 »
- Web side development »